==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkMergeFilter.java <==
// java wrapper for vtkMergeFilter object
//

package vtk;
import vtk.*;

public class vtkMergeFilter extends vtkDataSetAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetGeometryInputData_2(vtkDataSet id0);
  public void SetGeometryInputData(vtkDataSet id0)
    { SetGeometryInputData_2(id0); }

  private native long GetGeometry_3();
  public vtkDataSet GetGeometry() {
    long temp = GetGeometry_3();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetGeometryConnection_4(vtkAlgorithmOutput id0);
  public void SetGeometryConnection(vtkAlgorithmOutput id0)
    { SetGeometryConnection_4(id0); }

  private native void SetScalarsData_5(vtkDataSet id0);
  public void SetScalarsData(vtkDataSet id0)
    { SetScalarsData_5(id0); }

  private native long GetScalars_6();
  public vtkDataSet GetScalars() {
    long temp = GetScalars_6();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScalarsConnection_7(vtkAlgorithmOutput id0);
  public void SetScalarsConnection(vtkAlgorithmOutput id0)
    { SetScalarsConnection_7(id0); }

  private native void SetVectorsData_8(vtkDataSet id0);
  public void SetVectorsData(vtkDataSet id0)
    { SetVectorsData_8(id0); }

  private native long GetVectors_9();
  public vtkDataSet GetVectors() {
    long temp = GetVectors_9();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetVectorsConnection_10(vtkAlgorithmOutput id0);
  public void SetVectorsConnection(vtkAlgorithmOutput id0)
    { SetVectorsConnection_10(id0); }

  private native void SetNormalsData_11(vtkDataSet id0);
  public void SetNormalsData(vtkDataSet id0)
    { SetNormalsData_11(id0); }

  private native long GetNormals_12();
  public vtkDataSet GetNormals() {
    long temp = GetNormals_12();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetNormalsConnection_13(vtkAlgorithmOutput id0);
  public void SetNormalsConnection(vtkAlgorithmOutput id0)
    { SetNormalsConnection_13(id0); }

  private native void SetTCoordsData_14(vtkDataSet id0);
  public void SetTCoordsData(vtkDataSet id0)
    { SetTCoordsData_14(id0); }

  private native long GetTCoords_15();
  public vtkDataSet GetTCoords() {
    long temp = GetTCoords_15();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTCoordsConnection_16(vtkAlgorithmOutput id0);
  public void SetTCoordsConnection(vtkAlgorithmOutput id0)
    { SetTCoordsConnection_16(id0); }

  private native void SetTensorsData_17(vtkDataSet id0);
  public void SetTensorsData(vtkDataSet id0)
    { SetTensorsData_17(id0); }

  private native long GetTensors_18();
  public vtkDataSet GetTensors() {
    long temp = GetTensors_18();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTensorsConnection_19(vtkAlgorithmOutput id0);
  public void SetTensorsConnection(vtkAlgorithmOutput id0)
    { SetTensorsConnection_19(id0); }

  private native void AddField_20(String id0,vtkDataSet id1);
  public void AddField(String id0,vtkDataSet id1)
    { AddField_20(id0,id1); }

  public vtkMergeFilter() { super(); }

  public vtkMergeFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-18-armv7h.pkg.tar.xz: vtk/vtkMergeFilter.java <==
// java wrapper for vtkMergeFilter object
//

package vtk;
import vtk.*;

public class vtkMergeFilter extends vtkDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetGeometryInputData_2(vtkDataSet id0);
  public void SetGeometryInputData(vtkDataSet id0)
    { SetGeometryInputData_2(id0); }

  private native long GetGeometry_3();
  public vtkDataSet GetGeometry() {
    long temp = GetGeometry_3();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetGeometryConnection_4(vtkAlgorithmOutput id0);
  public void SetGeometryConnection(vtkAlgorithmOutput id0)
    { SetGeometryConnection_4(id0); }

  private native void SetScalarsData_5(vtkDataSet id0);
  public void SetScalarsData(vtkDataSet id0)
    { SetScalarsData_5(id0); }

  private native long GetScalars_6();
  public vtkDataSet GetScalars() {
    long temp = GetScalars_6();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScalarsConnection_7(vtkAlgorithmOutput id0);
  public void SetScalarsConnection(vtkAlgorithmOutput id0)
    { SetScalarsConnection_7(id0); }

  private native void SetVectorsData_8(vtkDataSet id0);
  public void SetVectorsData(vtkDataSet id0)
    { SetVectorsData_8(id0); }

  private native long GetVectors_9();
  public vtkDataSet GetVectors() {
    long temp = GetVectors_9();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetVectorsConnection_10(vtkAlgorithmOutput id0);
  public void SetVectorsConnection(vtkAlgorithmOutput id0)
    { SetVectorsConnection_10(id0); }

  private native void SetNormalsData_11(vtkDataSet id0);
  public void SetNormalsData(vtkDataSet id0)
    { SetNormalsData_11(id0); }

  private native long GetNormals_12();
  public vtkDataSet GetNormals() {
    long temp = GetNormals_12();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetNormalsConnection_13(vtkAlgorithmOutput id0);
  public void SetNormalsConnection(vtkAlgorithmOutput id0)
    { SetNormalsConnection_13(id0); }

  private native void SetTCoordsData_14(vtkDataSet id0);
  public void SetTCoordsData(vtkDataSet id0)
    { SetTCoordsData_14(id0); }

  private native long GetTCoords_15();
  public vtkDataSet GetTCoords() {
    long temp = GetTCoords_15();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTCoordsConnection_16(vtkAlgorithmOutput id0);
  public void SetTCoordsConnection(vtkAlgorithmOutput id0)
    { SetTCoordsConnection_16(id0); }

  private native void SetTensorsData_17(vtkDataSet id0);
  public void SetTensorsData(vtkDataSet id0)
    { SetTensorsData_17(id0); }

  private native long GetTensors_18();
  public vtkDataSet GetTensors() {
    long temp = GetTensors_18();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTensorsConnection_19(vtkAlgorithmOutput id0);
  public void SetTensorsConnection(vtkAlgorithmOutput id0)
    { SetTensorsConnection_19(id0); }

  private native void AddField_20(String id0,vtkDataSet id1);
  public void AddField(String id0,vtkDataSet id1)
    { AddField_20(id0,id1); }

  public vtkMergeFilter() { super(); }

  public vtkMergeFilter(long id) { super(id); }
  public native long   VTKInit();

}
